==> custom_pages-v1.12.9.zip: custom_pages/messages/es/base.php <==
<?php

return [
    '<strong>Add</strong> {templateName} item' => '<strong> Agregar </strong> elemento de {templateName}',
    '<strong>Custom</strong> Pages' => 'Páginas <strong>personalizadas</strong>',
    '<strong>Edit</strong> snippet' => '<strong>Editar</strong> el código',
    'Add' => 'Agregar',
    'Add a file icon before the title' => 'Agregar un ícono de archivo antes del título',
    'Additional IFrame Attributes' => 'Atributos adicionales del IFRAME',
    'Adds plain HTML content to your site.' => 'Agregar contenido HTML simple a su sitio.',
    'Advanced' => 'Avanzado',
    'Allows the user to manage custom pages.' => 'Permite al usuario administrar páginas personalizadas.',
    'Allows to add pages (markdown, iframe or links) to the space navigation' => 'Permite añadir páginas (markdown, iframe o enlaces) a la navegación del espacio',
    'Allows you to add content in MarkDown syntax.' => 'Le permite agregar contenido con la sintaxis de MarkDown.',
    'Alternate text' => 'Texto alternativo',
    'Always' => 'Siempre',
    'Always make a backup of your view files outside of your production environment!' => 'Siempre haga una copia de seguridad de sus archivos de visualización fuera del entorno de producción.',
    'An empty allowed template selection will allow all container templates for this container.' => 'Si no seleccionas ninguna plantilla se podrán utilizar todas las plantillas de contenedor en este contenedor.',
    'Back' => 'Volver',
    'Back to dashboard' => 'Volver al panel',
    'Back to overview' => 'Volver al resúmen',
    'Back to space' => 'Volver al espacio',
    'Can manage custom pages' => 'Puede administrar páginas personalizadas',
    'Cannot delete!' => '¡No se puede borrar!',
    'Category' => 'Categoría',
    'Configuration' => 'Configuración',
    'Content' => 'Contenido',
    'Create' => 'Crear',
    'Css Class' => 'Clase CSS',
    'Custom' => 'Personalizado',
    'Custom Pages' => 'Páginas personalizadas',
    'Custom pages' => 'Páginas personalizadas',
    'Dashboard' => 'Panel',
    'Default' => 'Por defecto',
    'Default Content' => 'Contenido por defecto',
    'Delete' => 'Borrar',
    'Deleted.' => 'Borrado.',
    'Edit' => 'Editar',
    'Edit Page' => 'Editar página',
    'Empty' => 'Vacío',
    'Empty content elements cannot be deleted!' => '¡No se pueden borrar elementos de contenido vacíos!',
    'File' => 'Archivo',
    'Footer menu' => 'Menú de pie de página',
    'General' => 'General',
    'Global Page' => 'Página global',
    'Global Widget' => 'Widget global',
    'Html' => 'Html',
    'ID' => 'ID',
    'Icon' => 'Icono',
    'Iframe' => 'Iframe',
    'Insert' => 'Insertar',
    'Invalid request data!' => 'Datos de solicitud no válidos',
    'Invalid template selection!' => 'Selección de plantilla no válida.',
    'Invalid type selection' => 'Tipo de selección inválido',
    'Invalid view file selection!' => '¡Selección de archivo de vista no válida!',
    'Link' => 'Link',
    'MarkDown' => 'MarkDown',
    'Menu settings' => 'Preferencias del menú',
    'Navigation' => 'Navegación',
    'On this page you can configure general settings of your custom pages.' => 'En esta página puedes configurar los ajustes generales de las páginas personalizadas.',
    'Overview' => 'Resúmen',
    'PHP' => 'PHP',
    'Page' => 'Página',
    'Page Content' => 'Contenido de la página',
    'Pages' => 'Páginas',
    'Panel' => 'Panel',
    'People Buttons' => 'Botones de personas',
    'Please choose one of the following content types. The content type defines how your content is embedded to your site.' => 'Por favor elige uno de los siguientes tipos de contenido. El tipo de contenido define cómo se inserta el contenido en tu sitio.',
    'Please keep in mind that php based pages are vulnerable to security issues, especially when handling user input. For more information, please have a look at <a href="{url}">Yii\'s Security best practices</a>.' => 'Por favor ten en cuenta que las páginas basadas en PHP son vulnerables a problemas de seguridad, especialmente si aceptan introducción de datos por parte de los usuarios. Para más información, por favor visita la <a href="{url}">página de buenas prácticas de seguridad de Yii</a>.',
    'Public' => 'Público',
    'Reset' => 'Borrar',
    'Reset the content to default value' => 'Reiniciar el contenido a su valor por defecto',
    'Select this setting for visible text nodes only. Uncheck this setting in case this element is used for example as HTML attribute value.' => 'Selecciona esta configuración sólo para nodos de texto visibles. Desmárcala si el elemento se utiliza por ejemplo como valor de un atributo HTML.',
    'Settings' => 'Ajustes',
    'Show additional file information (size)' => 'Mostrar información adicional del archivo (tamaño)',
    'Snippet' => 'Snippet',
    'Snippets' => 'Fragmentos',
    'Sort Order' => 'Ordenar por',
    'Source' => 'Fuente',
    'Space' => 'Espacio',
    'Space Members only' => 'Solo miembros del espacio',
    'Space Navigation' => 'Navegación por este espacio',
    'Space Page' => 'Página de espacio',
    'Space Widget' => 'Widget de espacio',
    'Spaces' => 'Espacios',
    'Stream' => 'Stream',
    'Stream options' => 'Opciones del stream',
    'Style' => 'Estilo',
    'Style Class' => 'Clase de estilo',
    'Submit' => 'Enviar',
    'Target Url' => 'URL de destino',
    'Template' => 'Plantilla',
    'Template Layout' => 'Diseño de plantilla',
    'Templates' => 'Plantillas',
    'Templates allow you to define combinable page fragments with inline edit functionality.' => 'Las plantillas te permiten definir elementos de página combinables con la posibilidad de ser editados directamente.',
    'This container does not allow any further items!' => '¡Este contenedor no admite ya más elementos!',
    'Title' => 'Título',
    'Top Navigation' => 'Navegación superior',
    'Topics' => 'Temas',
    'Type' => 'Tipo',
    'Upload image' => 'Subir imagen',
    'Usage' => 'Uso',
    'User Account Menu (Settings)' => 'Menú de cuenta de usuario (ajustes)',
    'Visibility' => 'Visibilidad',
    'Will embed the result of a given url as an iframe element.' => 'Incrustará el resultado de una URL determinada como un elemento iframe.',
    'Will redirect requests to a given (relative or absolute) url.' => 'Redirigirá las solicitudes a una URL determinada (relativa o absoluta).',
    'With PHP based pages you can create custom pages by means of view files in your file system. Please check the module configuration for more Information.' => 'Con páginas basadas en PHP puedes crear páginas personalizadas mediante ficheros de vista en tu sistema de ficheros. Para más información mira por favor la configuración del módulo.',
    'Without adding to navigation (Direct link)' => 'Sin añadir a la navegación (enlace directo)',
    'Wrap this HTML page with white panel' => 'Envolver esta página HTML con un panel blanco',
    'You are not allowed to delete default content!' => '¡No puedes eliminar contenido predeterminado!',
    'Administrative Users' => '',
    'Authors' => '',
    'Container' => '',
    'Content filters' => '',
    'Enter post content ID' => '',
    'Go Back' => '',
    'Import' => '',
    'Layout' => '',
    'Leave empty to list all records related to the current user.' => '',
    'Limit' => '',
    'Logged-In Users' => '',
    'Manage layouts, snippet layouts, and containers. Layouts define page structures, snippet layouts are used in sidebars or sections, and containers are reusable content blocks.' => '',
    'Non-Logged-In Users' => '',
    'Resources' => '',
    'Restrict to following comma separated content IDs' => '',
    'Start Page' => '',
];

==> custom_pages-v1.12.14.zip: custom_pages/messages/es/base.php <==
<?php

return [
    '<strong>Add</strong> {templateName} item' => '<strong> Agregar </strong> elemento de {templateName}',
    '<strong>Custom</strong> Pages' => 'Páginas <strong>personalizadas</strong>',
    '<strong>Edit</strong> snippet' => '<strong>Editar</strong> el código',
    'Add' => 'Agregar',
    'Add a file icon before the title' => 'Agregar un ícono de archivo antes del título',
    'Additional IFrame Attributes' => 'Atributos adicionales del IFRAME',
    'Adds plain HTML content to your site.' => 'Agregar contenido HTML simple a su sitio.',
    'Advanced' => 'Avanzado',
    'Allows the user to manage custom pages.' => 'Permite al usuario administrar páginas personalizadas.',
    'Allows to add pages (markdown, iframe or links) to the space navigation' => 'Permite añadir páginas (markdown, iframe o enlaces) a la navegación del espacio',
    'Allows you to add content in MarkDown syntax.' => 'Le permite agregar contenido con la sintaxis de MarkDown.',
    'Alternate text' => 'Texto alternativo',
    'Always' => 'Siempre',
    'Always make a backup of your view files outside of your production environment!' => 'Siempre haga una copia de seguridad de sus archivos de visualización fuera del entorno de producción.',
    'An empty allowed template selection will allow all container templates for this container.' => 'Si no seleccionas ninguna plantilla se podrán utilizar todas las plantillas de contenedor en este contenedor.',
    'Back' => 'Volver',
    'Back to dashboard' => 'Volver al panel',
    'Back to overview' => 'Volver al resúmen',
    'Back to space' => 'Volver al espacio',
    'Can manage custom pages' => 'Puede administrar páginas personalizadas',
    'Cannot delete!' => '¡No se puede borrar!',
    'Category' => 'Categoría',
    'Configuration' => 'Configuración',
    'Content' => 'Contenido',
    'Create' => 'Crear',
    'Css Class' => 'Clase CSS',
    'Custom' => 'Personalizado',
    'Custom Pages' => 'Páginas personalizadas',
    'Custom pages' => 'Páginas personalizadas',
    'Dashboard' => 'Panel',
    'Default' => 'Por defecto',
    'Default Content' => 'Contenido por defecto',
    'Delete' => 'Borrar',
    'Deleted.' => 'Borrado.',
    'Edit' => 'Editar',
    'Edit Page' => 'Editar página',
    'Empty' => 'Vacío',
    'Empty content elements cannot be deleted!' => '¡No se pueden borrar elementos de contenido vacíos!',
    'File' => 'Archivo',
    'Footer menu' => 'Menú de pie de página',
    'General' => 'General',
    'Global Page' => 'Página global',
    'Global Widget' => 'Widget global',
    'Html' => 'Html',
    'ID' => 'ID',
    'Icon' => 'Icono',
    'Iframe' => 'Iframe',
    'Insert' => 'Insertar',
    'Invalid request data!' => 'Datos de solicitud no válidos',
    'Invalid template selection!' => 'Selección de plantilla no válida.',
    'Invalid type selection' => 'Tipo de selección inválido',
    'Invalid view file selection!' => '¡Selección de archivo de vista no válida!',
    'Link' => 'Link',
    'MarkDown' => 'MarkDown',
    'Menu settings' => 'Preferencias del menú',
    'Navigation' => 'Navegación',
    'On this page you can configure general settings of your custom pages.' => 'En esta página puedes configurar los ajustes generales de las páginas personalizadas.',
    'Overview' => 'Resúmen',
    'PHP' => 'PHP',
    'Page' => 'Página',
    'Page Content' => 'Contenido de la página',
    'Pages' => 'Páginas',
    'Panel' => 'Panel',
    'People Buttons' => 'Botones de personas',
    'Please choose one of the following content types. The content type defines how your content is embedded to your site.' => 'Por favor elige uno de los siguientes tipos de contenido. El tipo de contenido define cómo se inserta el contenido en tu sitio.',
    'Please keep in mind that php based pages are vulnerable to security issues, especially when handling user input. For more information, please have a look at <a href="{url}">Yii\'s Security best practices</a>.' => 'Por favor ten en cuenta que las páginas basadas en PHP son vulnerables a problemas de seguridad, especialmente si aceptan introducción de datos por parte de los usuarios. Para más información, por favor visita la <a href="{url}">página de buenas prácticas de seguridad de Yii</a>.',
    'Public' => 'Público',
    'Reset' => 'Borrar',
    'Reset the content to default value' => 'Reiniciar el contenido a su valor por defecto',
    'Select this setting for visible text nodes only. Uncheck this setting in case this element is used for example as HTML attribute value.' => 'Selecciona esta configuración sólo para nodos de texto visibles. Desmárcala si el elemento se utiliza por ejemplo como valor de un atributo HTML.',
    'Settings' => 'Ajustes',
    'Show additional file information (size)' => 'Mostrar información adicional del archivo (tamaño)',
    'Snippet' => 'Snippet',
    'Snippets' => 'Fragmentos',
    'Sort Order' => 'Ordenar por',
    'Source' => 'Fuente',
    'Space' => 'Espacio',
    'Space Members only' => 'Solo miembros del espacio',
    'Space Navigation' => 'Navegación por este espacio',
    'Space Page' => 'Página de espacio',
    'Space Widget' => 'Widget de espacio',
    'Spaces' => 'Espacios',
    'Stream' => 'Stream',
    'Stream options' => 'Opciones del stream',
    'Style' => 'Estilo',
    'Style Class' => 'Clase de estilo',
    'Submit' => 'Enviar',
    'Target Url' => 'URL de destino',
    'Template' => 'Plantilla',
    'Template Layout' => 'Diseño de plantilla',
    'Templates' => 'Plantillas',
    'Templates allow you to define combinable page fragments with inline edit functionality.' => 'Las plantillas te permiten definir elementos de página combinables con la posibilidad de ser editados directamente.',
    'This container does not allow any further items!' => '¡Este contenedor no admite ya más elementos!',
    'Title' => 'Título',
    'Top Navigation' => 'Navegación superior',
    'Topics' => 'Temas',
    'Type' => 'Tipo',
    'Upload image' => 'Subir imagen',
    'Usage' => 'Uso',
    'User Account Menu (Settings)' => 'Menú de cuenta de usuario (ajustes)',
    'Visibility' => 'Visibilidad',
    'Will embed the result of a given url as an iframe element.' => 'Incrustará el resultado de una URL determinada como un elemento iframe.',
    'Will redirect requests to a given (relative or absolute) url.' => 'Redirigirá las solicitudes a una URL determinada (relativa o absoluta).',
    'With PHP based pages you can create custom pages by means of view files in your file system. Please check the module configuration for more Information.' => 'Con páginas basadas en PHP puedes crear páginas personalizadas mediante ficheros de vista en tu sistema de ficheros. Para más información mira por favor la configuración del módulo.',
    'Without adding to navigation (Direct link)' => 'Sin añadir a la navegación (enlace directo)',
    'Wrap this HTML page with white panel' => 'Envolver esta página HTML con un panel blanco',
    'You are not allowed to delete default content!' => '¡No puedes eliminar contenido predeterminado!',
    'Activities' => '',
    'Activity' => '',
    'Activity content ID' => '',
    'Administrative Users' => '',
    'Authors' => '',
    'By creation date' => '',
    'By last update' => '',
    'Container' => '',
    'Content filters' => '',
    'Determine which Spaces should be taken into account.' => '',
    'Enter post content ID' => '',
    'Go Back' => '',
    'Import' => '',
    'Include all Spaces except selected' => '',
    'Include selected Spaces only' => '',
    'Layout' => '',
    'Leave empty to list all records related to the current user.' => '',
    'Limit' => '',
    'Logged-In Users' => '',
    'Manage layouts, snippet layouts, and containers. Layouts define page structures, snippet layouts are used in sidebars or sections, and containers are reusable content blocks.' => '',
    'Non-Logged-In Users' => '',
    'Resources' => '',
    'Restrict to following comma separated content IDs' => '',
    'Sorting' => '',
    'Space selection' => '',
    'Start Page' => '',
];
